<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.multidots.com/
 * @since      1.0.0
 *
 * @package    Woo_Order_Delivery_Date
 * @subpackage Woo_Order_Delivery_Date/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woo_Order_Delivery_Date
 * @subpackage Woo_Order_Delivery_Date/admin
 * @author     multidots <info@multidots.in>
 */
class Woocommerce_Order_Delivery_Date_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Woocommerce_Order_Delivery_Date_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Woocommerce_Order_Delivery_Date_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        if (isset($_GET['page']) && !empty($_GET['page']) && ($_GET['page'] == 'wc_order_delivery_date' || $_GET['page'] == 'import_zipcode')) {
            wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/woocommerce-order-delivery-date-admin.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . '-ki', plugin_dir_url(__FILE__) . 'css/webkit.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . '-main-style', plugin_dir_url(__FILE__) . 'css/style.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . '-media', plugin_dir_url(__FILE__) . 'css/media.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . '-font-awesome', plugin_dir_url(__FILE__) . 'css/font-awesome.min.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . '-ui', plugin_dir_url(__FILE__) . 'css/jquery-ui.css', array());
        }
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Woocommerce_Order_Delivery_Date_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Woocommerce_Order_Delivery_Date_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        if (isset($_GET['page']) && !empty($_GET['page']) && ($_GET['page'] == 'wc_order_delivery_date' || $_GET['page'] == 'import_zipcode')) {
            wp_enqueue_script($this->plugin_name . '-ui', plugin_dir_url(__FILE__) . 'js/jquery-ui.js', array());
            wp_enqueue_script($this->plugin_name . '-multidatespicker', plugin_dir_url(__FILE__) . 'js/jquery-ui.multidatespicker.js', array());
            wp_enqueue_script($this->plugin_name . '-datepicker', plugin_dir_url(__FILE__) . 'js/multipledate_picker.js', array());
            wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/woocommerce-order-delivery-date-admin.js', array('jquery'), $this->version, false);
            wp_localize_script('woocommerce-order-delivery-date', 'wcodd_ajax_params', array('ajax_url' => admin_url('admin-ajax.php')));
            wp_enqueue_script($this->plugin_name . '-ui', plugin_dir_url(__FILE__) . 'js/jquery-ui.js', array());
            wp_enqueue_script($this->plugin_name . '-multidatespicker', plugin_dir_url(__FILE__) . 'js/jquery-ui.multidatespicker.js', array());
        }
    }

    /**
     * Function For Admin Menu Save data 
     *
     */
    public function wcodd_add_update_options() {

// delivery date settings 
        $getmultiselectdates = isset($_POST['wcodd_selectdate']) && !empty($_POST['wcodd_selectdate']) ? $_POST['wcodd_selectdate'] : '';
        $getmultiselectdays = isset($_POST['wcodd_inactive_day']) && !empty($_POST['wcodd_inactive_day']) ? $_POST['wcodd_inactive_day'] : '';
        $order_by_weekend_amount = isset($_POST['order_by_weekend_amount']) && !empty($_POST['order_by_weekend_amount']) ? $_POST['order_by_weekend_amount'] : '';
        $getmultiselectstander_date = isset($_POST['stander_order_delivery_date']) && !empty($_POST['stander_order_delivery_date']) ? $_POST['stander_order_delivery_date'] : '';
        $getmultiselectstander_message = isset($_POST['order_delivery_message']) && !empty($_POST['order_delivery_message']) ? $_POST['order_delivery_message'] : '';
        $order_delivery_day_count = isset($_POST['order_delivery_day_count']) && !empty($_POST['order_delivery_day_count']) ? $_POST['order_delivery_day_count'] : '';

        $orderbased_settings_plugin_option_enable = isset($_POST['plugin_option_enable']) && !empty($_POST['plugin_option_enable']) ? $_POST['plugin_option_enable'] : '';
        $orderbased_settings_order_delivery_option_enable = isset($_POST['order_delivery_option_enable']) && !empty($_POST['order_delivery_option_enable']) ? $_POST['order_delivery_option_enable'] : '';
        $orderbased_settings_order_delivery_date_field_option_enable = isset($_POST['order_delivery_date_field_option_enable']) && !empty($_POST['order_delivery_date_field_option_enable']) ? $_POST['order_delivery_date_field_option_enable'] : '';
        $orderbased_settings_order_delivery_checkout_page_label = isset($_POST['order_delivery_checkout_page_label']) && !empty($_POST['order_delivery_checkout_page_label']) ? $_POST['order_delivery_checkout_page_label'] : '';
        $orderbased_settings_order_delivery_date_option_to_customer_email = isset($_POST['order_delivery_date_option_to_customer_email']) && !empty($_POST['order_delivery_date_option_to_customer_email']) ? $_POST['order_delivery_date_option_to_customer_email'] : '';
//$orderbased_settings_order_delivery_date_option_to_review_page = !empty( $_POST['order_delivery_date_option_to_review_page']) ? $_POST['order_delivery_date_option_to_review_page'] : '';
        $orderbased_settings_order_delivery_date_option_to_order_thank_you_page = isset($_POST['order_delivery_date_option_to_order_thank_you_page']) && !empty($_POST['order_delivery_date_option_to_order_thank_you_page']) ? $_POST['order_delivery_date_option_to_order_thank_you_page'] : '';

        $order_delivery_excepted_date_before_order = isset($_POST['order_delivery_excepted_date_before_order']) && !empty($_POST['order_delivery_excepted_date_before_order']) ? $_POST['order_delivery_excepted_date_before_order'] : '';
        $order_delivery_excepted_date_before_order_extra_cost = isset($_POST['order_delivery_excepted_date_before_order_extra_cost']) && !empty($_POST['order_delivery_excepted_date_before_order_extra_cost']) ? $_POST['order_delivery_excepted_date_before_order_extra_cost'] : '';
        $order_delivery_both_extra_cost = isset($_POST['order_delivery_both_extra_cost']) && !empty($_POST['order_delivery_both_extra_cost']) ? $_POST['order_delivery_both_extra_cost'] : '';


        $wcaodoptionarray = array();
        $wcaodoptionarray['multiselectdate'] = $getmultiselectdates;
        $wcaodoptionarray['selecteddays'] = $getmultiselectdays;
        $wcaodoptionarray['selectstanderdorderdate'] = $getmultiselectstander_date;
        $wcaodoptionarray['selectstanderdordermessage'] = $getmultiselectstander_message;
        $wcaodoptionarray['order_delivery_day_count'] = $order_delivery_day_count;
        $wcaodoptionarray['order_by_weekend_amount'] = $order_by_weekend_amount;

//delivery date settings save

        $wcaodoptionarray['pluginoptionenable'] = $orderbased_settings_plugin_option_enable;
        $wcaodoptionarray['orderdeliveryoptionenable'] = $orderbased_settings_order_delivery_option_enable;
        $wcaodoptionarray['orderdeliverydatefieldoptionenable'] = $orderbased_settings_order_delivery_date_field_option_enable;
        $wcaodoptionarray['orderdeliverycheckoutpagelabel'] = $orderbased_settings_order_delivery_checkout_page_label;

        $wcaodoptionarray['order_delivery_excepted_date_before_order'] = $order_delivery_excepted_date_before_order;
        $wcaodoptionarray['order_delivery_excepted_date_before_order_extra_cost'] = $order_delivery_excepted_date_before_order_extra_cost;
        $wcaodoptionarray['order_delivery_both_extra_cost'] = $order_delivery_both_extra_cost;


// delivery order date saving 
        $order_delivery_enable_disable_date = !empty($_POST['order_delivery_enable_disable_date']) ? $_POST['order_delivery_enable_disable_date'] : '';
        $wcaodoptionarray['order_delivery_enable_disable_date'] = $order_delivery_enable_disable_date;
        $wcaodoptionarray['order_delivery_enable_disable_date_publick'] = str_replace(" ", "", $order_delivery_enable_disable_date);
        $wcaodoptionarray = maybe_serialize($wcaodoptionarray);
        update_option('wcodd_option', $wcaodoptionarray);
        wp_safe_redirect(site_url("/wp-admin/admin.php?page=wc_order_delivery_date&success=1"));
        exit();
    }

    /**
     * Function For Redirect after activation of plugin
     *
     */
    public function welcome_order_delivery_date_screen_do_activation_redirect() {
        if (!get_transient('_welcome_screen_order_delivery_date_mode_activation_redirect_data')) {
            return;
        }

// Delete the redirect transient
        delete_transient('_welcome_screen_order_delivery_date_mode_activation_redirect_data');

// if activating from network, or bulk
        if (is_network_admin() || isset($_GET['activate-multi'])) {
            return;
        }
// Redirect to Delivery Ordar date welcome  page
        wp_safe_redirect(add_query_arg(array('page' => 'wc_order_delivery_date&tab=get-started-dots-about-plugin-settings'), admin_url('admin.php')));
    }

    public function custom_order_delivery_date_pointers_footer() {
        $admin_pointers = custom_order_delivery_date_admin_pointers();
    }

    /**
     * remove menu in deshboard
     * 
     */
    public function adjust_the_wp_menu() {
        remove_submenu_page('index.php', 'woocommerce-order-delivery-date');
    }

    /**
     * Function For add new menu in theme option 
     * 
     * 
     */
    public function dot_store_menu() {
        global $GLOBALS;
        if (empty($GLOBALS['admin_page_hooks']['dots_store'])) {
            add_menu_page(
                    'DotStore Plugins', 'DotStore Plugins', 'manage_option', 'dots_store', array($this, 'dot_store_menu_page'), plugin_dir_url(__FILE__) . 'images/menu-icon.png', 25
            );
        }
    }

    /**
     * Default dots store main page
     *
     */
    public function dot_store_menu_page() {
        
    }

    /**
     * Add Sub menu page
     *
     */
    public function add_new_menu_items() {

        add_submenu_page("dots_store", "WooCommerce Order Delivery Date", "WooCommerce Order Delivery Date", "manage_options", "wc_order_delivery_date", array($this, "wc_order_delivery_options_page"), "", 99);
    }

    /**
     * Order Delivery Option Page HTML
     *
     */
    public function wc_order_delivery_options_page() {
        global $post_type, $pagenow;
        include_once('partials/header/plugin-header.php');

        $active_tab = "delivery-date-settings";
        if (!empty($_GET["tab"])) {

            if ($_GET["tab"] == "delivery-date-settings") {
                delivery_order_settings_store();
            }

            if ($_GET['tab'] === 'dots-about-plugin-settings') {
                dotstore_about_plugin_store();
            }
            if ($_GET['tab'] === 'dots-contact-supports-store-plugin-settings') {
                contact_supports_dotstore_plugin_settings();
            }
            if ($_GET['tab'] === 'get-started-dots-about-plugin-settings') {
                get_started_dots_about_plugin_settings();
            }
            if ($_GET['tab'] === 'dotstore_introduction_order_delivery_date') {
                order_delivery_plugin_introduction();
            }
            if ($_GET['tab'] === 'dotstore_premium_order_delivery_date') {
                wcodd_plugin_premium_tab();
            }
        } else {
            delivery_order_settings_store();
        }
        ?>

        <!-- end here !-->	
        <?php include_once('partials/header/plugin-sidebar.php'); ?>

        </div>

        </div>
        </body>			
        <html>

            <?php
        }

        public function wc_order_delivery_remove_view_zipcode_post_link($actions, $post) {
            if ($post->post_type == 'zipcode_listing') {
                unset($actions['view']);
            }
            return $actions;
        }

        public function wc_order_delivery_custom_plugin_header() {
            global $post_type, $pagenow;
            if ((isset($_GET['post_type']) && $_GET['post_type'] == 'zipcode_listing') || ($post_type == 'zipcode_listing')) :
            //include_once('partials/header/plugin-header.php');
            endif;
        }

        public function wc_order_delivery_custom_plugin_header_style() {
            global $post_type;

            if ((isset($_GET['post_type']) && $_GET['post_type'] == 'zipcode_listing') || ($post_type == 'zipcode_listing')) :
                echo "<link type='text/css' rel='stylesheet' href='" . plugins_url('/css/style.css', __FILE__) . "' />";
            endif;
        }

        public function wp_add_plugin_userfn_free_wcood() {

            $email_id = (isset($_POST["email_id"]) && !empty($_POST["email_id"])) ? $_POST["email_id"] : '';
            $log_url = $_SERVER['HTTP_HOST'];
            $cur_date = date('Y-m-d');
            $request_url = 'http://www.multidots.com/store/wp-content/themes/business-hub-child/API/wp-add-plugin-users.php';
            if (!empty($email_id)) {
                $request_response = wp_remote_post($request_url, array('method' => 'POST',
                    'timeout' => 45,
                    'redirection' => 5,
                    'httpversion' => '1.0',
                    'blocking' => true,
                    'headers' => array(),
                    'body' => array('user' => array('plugin_id' => '41', 'user_email' => $email_id, 'plugin_site' => $log_url, 'status' => 1, 'activation_date' => $cur_date)),
                    'cookies' => array()));
                 update_option('wcodd_free_dialog_plugin_notice_shown', 'true');
            }
        }

    }

    /**
     * Custom menu html for Home page menu
     *
     */
    function dotstore_about_plugin_store() {

        $plugin_name = WCODD_PLUGIN_NAME;
        $plugin_version = WCODD_PLUGIN_VERSION;
        ?> 

        <div class="wcodd-table-main res-cl">
            <h2>Introduction</h2>
            <table class="wcodd-tableouter">
                <tbody>
                    <tr>
                        <td class="fr-1">Product Type</td>
                        <td class="fr-2">WordPress Plugin</td>
                    </tr>
                    <tr>
                        <td class="fr-1">Product Name</td>
                        <td class="fr-2"><?php echo $plugin_name; ?></td>
                    </tr>
                    <tr>
                        <td class="fr-1">Installed Version</td>
                        <td class="fr-2"><?php echo $plugin_version; ?></td>
                    </tr>
                    <tr>
                        <td class="fr-1">License & Terms of use</td>
                        <td class="fr-2"><a href="#">Click here</a> to view license and terms of use.</td>
                    </tr>
                    <tr>
                        <td class="fr-1">Help & Support</td>
                        <td class="fr-2">
                            <ul class="help-support">
                                <li><a target="_blank" href="<?php echo site_url('wp-admin/admin.php?page=flate_rate_shipping_method_pro&tab=wc_pro_extra_shipping_get_started_method'); ?>">Quick Start Guide</a></li>
                                <li><a target="_blank" href="https://store.multidots.com/docs/plugin/advanced-flat-rate-shipping-method-for-woocommerce/">Documentation</a></li>
                                <li><a target="_blank" href="https://store.multidots.com/dotstore-support-panel/">Support Forum</a></li>
                            </ul>
                        </td>
                    </tr>
                    <tr>
                        <td class="fr-1">Localization</td>
                        <td class="fr-2">English, Spanish</td>
                    </tr>

                </tbody>
            </table>
        </div>
        <?php
    }

    /**
     * function for custom get started page 
     *
     */
    function get_started_dots_about_plugin_settings() {

        $plugin_name = WCODD_PLUGIN_NAME;
        $plugin_version = WCODD_PLUGIN_VERSION;
        $current_user = wp_get_current_user();
        if (!get_option('wcodd_free_dialog_plugin_notice_shown')) {
            echo '<div id="wcodd_free_dialog"> <p> Be the first to get latest updates and exclusive content straight to your email inbox. </p> <p><input type="text" id="txt_user_sub_pvcp" class="regular-text" name="txt_user_sub_pvcp" value="' . $current_user->user_email . '"></p></div>';
        }
        ?>			
        <div class="wcodd-table-main res-cl">
            <h2>Thanks For Installing WooCommerce Order Delivery Date Plugin</h2>
            <table class="wcodd-tableouter">
                <tbody>
                    <tr>
                        <td class="fr-2">
                            <p class="block gettingstarted"><strong>Getting Started</strong></p>
                            <p class="block textgetting">This plugin lets you offer your customers the ability to choose the delivery date of their choice.You can charge the customers based on their chosen delivery dates.</p>
                            <p class="block textgetting">
                                <strong>Step 1 :</strong> Select the options required for your shop from the settings screen.
                                <span class="gettingstarted"><img style="border: 2px solid #e9e9e9;margin-top: 3%;" src="<?php echo WODD_PLUGIN_URL . 'admin/images/Getting_Started_01.png'; ?>"></span>
                            </p>
                            <p class="block textgetting">
                                <strong>Step 2 :</strong> If you want to offer estimated order delivery dates based on zip code in shipping address, checkmark the box "enable zipcode based order delivery date calculation."<span class="avblpro">(Available in PRO)</span>
                                <span class="gettingstarted"><img style="border: 2px solid #e9e9e9;margin-top: 3%;" src="<?php echo WODD_PLUGIN_URL . 'admin/images/Getting_Started_02.png'; ?>"></span>
                            </p>
                            <p class="block textgetting">
                                <strong>Step 3 :</strong> Upload zip codes or Add zip codes with number of delivery days required for each zip code.<span class="avblpro">(Available in PRO)</span>
                                <span class="gettingstarted"><img style="border: 2px solid #e9e9e9;margin-top: 3%;" src="<?php echo WODD_PLUGIN_URL . 'admin/images/Getting_Started_03.png'; ?>"></span>
                            </p>
                        </td>
                    </tr>
                </tbody>
            </table>
        </div>
        <?php
    }

    /**
     * function for custom get started page 
     *
     */
    function order_delivery_plugin_introduction() {
        $plugin_name = WCODD_PLUGIN_NAME;
        $plugin_version = WCODD_PLUGIN_VERSION;
        ?>			
        <div class="wcodd-table-main res-cl">
            <h2>Quick info</h2>
            <table class="wcodd-tableouter">
                <tbody>
                    <tr>
                        <td class="fr-1">Product Type</td>
                        <td class="fr-2">WooCommerce Plugin</td>
                    </tr>
                    <tr>
                        <td class="fr-1">Product Name</td>
                        <td class="fr-2"><?php echo $plugin_name; ?></td>
                    </tr>
                    <tr>
                        <td class="fr-1">Installed Version</td>
                        <td class="fr-2"><?php echo $plugin_version; ?></td>
                    </tr>
                    <tr>
                        <td class="fr-1">License & Terms of use</td>
                        <td class="fr-2"> <a target="_blank"  href=" https://store.multidots.com/terms-conditions/">Click here</a> to view license and terms of use.</td>
                    </tr>
                    <tr>
                        <td class="fr-1">Help & Support</td>
                        <td class="fr-2">
                            <ul class="help-support">
                                <li><a href="<?php echo site_url('wp-admin/admin.php?page=wc_order_delivery_date&tab=get-started-dots-about-plugin-settings'); ?>">Quick Start Guide</a></li>
                                <li><a target="_blank" href="https://store.multidots.com/docs/plugins/woocommerce-order-delivery-date/">Documentation</a></li>
                                <li><a target="_blank" href="https://store.multidots.com/dotstore-support-panel/">Support Forum</a></li>
                            </ul>
                        </td>
                    </tr>
                    <tr>
                        <td class="fr-1">Localization</td>
                        <td class="fr-2">English, Spanish</td>
                    </tr>

                </tbody>
            </table>
        </div>
        <?php
    }

    function wcodd_plugin_premium_tab() {
        ?>


        <div class="wcodd-table-main res-cl key-featured">
            <h2>Free vs Pro </h2>
            <table class="wcodd-tableouter premium-free-table" align="center">
                <thead>
                    <tr class="blue">
                        <th>KEY FEATURES LIST</th>
                        <th>FREE</th>
                        <th>PRO</th>
                    </tr>
                </thead>
                <tbody class="wcodd-premium">
                    <tr class="dark">
                        <td class="pad"><?php _e('Enable Delivery Date Selection on Checkouts'); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr>
                        <td class="pad"><?php _e('Set Delivery Date field mandatory on Checkout'); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr class="dark">
                        <td class="pad"><?php _e('Change Label of Delivery Date field'); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr>
                        <td class="pad"><?php _e('Set Standard Delivery Days '); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr class="dark">
                        <td class="pad"><?php _e('Allow scheduling delivery before expected delivery date '); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr>
                        <td class="pad"><?php _e('Block dates for delivery '); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>

                    <tr class="dark">
                        <td class="pad"><?php _e('Set Week-off days - the days when you do not make deliveries'); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/trash.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr>
                        <td class="pad"><?php _e('Enable week-off day extra cost to charge the customer, if the chosen delivery date is a week-off day'); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/trash.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr class="dark">
                        <td class="pad"><?php _e('Enable zipcode based delivery date settings.'); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/trash.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr>
                        <td class="pad"><?php _e('Add zipcode and delivery days '); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/trash.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr class="dark">
                        <td class="pad"><?php _e('You can add multiple zipcodes-delivery days data OR upload a .csv file having this data, to import data in batch.'); ?></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/trash.png'; ?>"></td>
                        <td><img src="<?php echo WODD_PLUGIN_URL . 'admin/images/check-mark.png'; ?>"></td>
                    </tr>
                    <tr class="pad radius-s">
                        <td class="pad"></td>
                        <td></td>
                        <td class="green red"><a href="https://store.multidots.com/woocommerce-order-delivery-date/" target="_blank">UPGRADE TO <br> PREMIUM VERSION </a></td>
                    </tr>
                </tbody>
            </table>
        </div>


        <?php
    }

    /**
     * Custom menu html
     *
     */
    function delivery_order_settings_store() {
        global $wpdb;
        $getwcoddoption = get_option('wcodd_option');
        $getwcoddoptionArray = maybe_unserialize($getwcoddoption);


        $weekdayarray = array("Sun" => "Sunday", "Mon" => "Monday", "Tue" => "Tuesday", "Wed" => "Wednesday", "Thu" => "Thursday", "Fri" => "Friday", "Sat" => "Saturday");
        $standerd_date = '4';
        $standerd_message = '';
        $daycount = '0';
        //var_dump($getwcoddoptionArray['order_by_weekend_amount']);

        if (!empty($getwcoddoptionArray['selectstanderdorderdate'])) {
            $getwcoddoptionresults_array = $getwcoddoptionArray['selectstanderdorderdate'];
            if (!empty($getwcoddoptionresults_array)) {
                $standerd_date = $getwcoddoptionresults_array;
            }
        }

        if (!empty($getwcoddoptionArray['selectstanderdordermessage'])) {
            $getwcoddoptionresults_message = $getwcoddoptionArray['selectstanderdordermessage'];

            if (!empty($getwcoddoptionresults_message)) {
                $standerd_message = $getwcoddoptionresults_message;
            }
        }

        if (!empty($getwcoddoptionArray['order_delivery_day_count'])) {
            $getwcoddoptionresults_daycount = $getwcoddoptionArray['order_delivery_day_count'];

            if (!empty($getwcoddoptionresults_daycount)) {
                $daycount = $getwcoddoptionresults_daycount;
            }
        }

        //delivery date settings save
        $orderdeliveryoptionenable = '';
        $orderdeliverydatefieldoptionenable = '';
        $orderdeliverycheckoutpagelabel = '';
        //$orderdeliverydateoptiontocustomeremail = '';
        //$orderdeliverydateoptiontoreviewpage = '';
        //$orderdeliverydateoptiontoorderthankyoupage = '';

        if (isset($getwcoddoptionArray['orderdeliveryoptionenable']) && !empty($getwcoddoptionArray['orderdeliveryoptionenable']) && $getwcoddoptionArray['orderdeliveryoptionenable'] != '') {
            $orderdeliveryoptionenable = "checked";
        }
        if (isset($getwcoddoptionArray['orderdeliverydatefieldoptionenable']) && !empty($getwcoddoptionArray['orderdeliverydatefieldoptionenable']) && $getwcoddoptionArray['orderdeliverydatefieldoptionenable'] != '') {
            $orderdeliverydatefieldoptionenable = "checked";
        }

        if (isset($getwcoddoptionArray['orderdeliverycheckoutpagelabel']) && !empty($getwcoddoptionArray['orderdeliverycheckoutpagelabel']) && $getwcoddoptionArray['orderdeliverycheckoutpagelabel'] != '') {
            $orderdeliverycheckoutpagelabel = $getwcoddoptionArray['orderdeliverycheckoutpagelabel'];
        }

        $order_delivery_excepted_date_before_order_enable = '';
        $order_delivery_excepted_date_before_order_extra_cost = '';
        $order_delivery_both_extra_cost = '';

        if (isset($getwcoddoptionArray['order_delivery_excepted_date_before_order']) && !empty($getwcoddoptionArray['order_delivery_excepted_date_before_order']) && $getwcoddoptionArray['order_delivery_excepted_date_before_order'] != '') {
            $order_delivery_excepted_date_before_order_enable = "checked";
        }

        if (isset($getwcoddoptionArray['order_delivery_excepted_date_before_order_extra_cost']) && !empty($getwcoddoptionArray['order_delivery_excepted_date_before_order_extra_cost']) && $getwcoddoptionArray['order_delivery_excepted_date_before_order_extra_cost'] != '') {
            $order_delivery_excepted_date_before_order_extra_cost = $getwcoddoptionArray['order_delivery_excepted_date_before_order_extra_cost'];
        }

        if (isset($getwcoddoptionArray['order_delivery_both_extra_cost']) && !empty($getwcoddoptionArray['order_delivery_both_extra_cost']) && $getwcoddoptionArray['order_delivery_both_extra_cost'] != '') {
            $order_delivery_both_extra_cost = "checked";
        }
        ?>
        <div class="wcodd-table-main">
            <form id="cw_plugin_form_id" method="post" action="<?php echo get_admin_url(); ?>admin-post.php" enctype="multipart/form-data" novalidate="novalidate"> 
                <input type='hidden' name='action' value='submit_form_wcodd' />
                <input type='hidden' name='action-which' value='add' />
                <input type="hidden" name="add_wcodd_multidatepicker" id="add_wcodd_multidatepicker" value="<?php echo $getwcoddoptionArray['order_delivery_enable_disable_date']; ?>"/>   
                <?php if (isset($_GET['success'])) { ?>
                    <div class="updated notice"><p>Your setting has been saved.</p></div>
                <?php } ?>
                <div class="under-table third-tab">
                    <div class="set">
                        <input name="submit" id="submit" width = "50%" height="15px" class="button button-primary" value="Save Changes" type="submit">
                    </div>
                    <table class="wcodd-tableouter">
                        <tbody>
                            <tr>
                                <td class="ur-1"><?php _e("Enable Order Delivery Date Plugin Features", WCODD_PLUGIN_SLUG); ?></td>
                                <td class="ur-2">
                                    <input <?php
                                    if ((isset($getwcoddoptionArray['pluginoptionenable']) && !empty($getwcoddoptionArray['pluginoptionenable']) && $getwcoddoptionArray['pluginoptionenable'] != '' && $getwcoddoptionArray['pluginoptionenable'] == 'on' ) || !isset($getwcoddoptionArray['pluginoptionenable'])) {
                                        echo 'checked';
                                    }
                                    ?> type="checkbox" name="plugin_option_enable"  value="on">
                                    <span class="order_delivery_tab_descirtion"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php _e('Checkmark this box to enable all features of WooCommerce order delivery date plugin.', WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr>
                            <tr>
                                <td class="ur-1"><?php _e("Enable Delivery Date Selection on Checkout", WCODD_PLUGIN_SLUG); ?>s</td>
                                <td class="ur-2">
                                    <input <?php
                                    if (isset($getwcoddoptionArray['orderdeliveryoptionenable']) && !empty($getwcoddoptionArray['orderdeliveryoptionenable']) && $getwcoddoptionArray['orderdeliveryoptionenable'] != '' && $getwcoddoptionArray['orderdeliveryoptionenable'] == 'on') {
                                        
                                    }
                                    ?> type="checkbox" name="order_delivery_option_enable"  value="on" checked="">
                                    <span class="order_delivery_tab_descirtion"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php _e('Checkmark this box to let customers select delivery date on checkout.', WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr>

                            <tr>
                                <td class="ur-1"><?php _e("Set Delivery Date field mandatory on Checkout", WCODD_PLUGIN_SLUG); ?></td>
                                <td class="ur-2">
                                    <input <?php
                                    if (isset($getwcoddoptionArray['orderdeliverydatefieldoptionenable']) && !empty($getwcoddoptionArray['orderdeliverydatefieldoptionenable']) && $getwcoddoptionArray['orderdeliverydatefieldoptionenable'] == 'on') {
                                        echo $orderdeliverydatefieldoptionenable;
                                    }
                                    ?> type="checkbox" name="order_delivery_date_field_option_enable"  value="on" checked="">
                                    <span class="order_delivery_tab_descirtion"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php _e("Checkmark this box to make selection of delivery date mandatory.", WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr> 

                            <tr>
                                <td class="ur-1"><?php _e("Change Label of Delivery Date field", WCODD_PLUGIN_SLUG); ?></td>
                                <td class="ur-2">
                                    <input type="text" value="<?php echo $orderdeliverycheckoutpagelabel; ?>" placeholder="Checkout page label" name="order_delivery_checkout_page_label" class="input-text regular-input" maxlength="50">
                                    <span class="order_delivery_tab_descirtion"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php _e("You can add your own label for the delivery date field, to be displayed on the checkout page.", WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr>
                            <tr>
                                <td class="ur-1"><?php _e(WCODD_PLUGIN_STANDARD_DELIVERY_DAY, WCODD_PLUGIN_SLUG); ?></td>
                                <td class="ur-2">
                                    <input type="number" required="true" min="0" name="stander_order_delivery_date" class="onlyNumber input-text regular-input" value="<?php echo $standerd_date; ?>">
                                    <span class="order_delivery_tab_descirtion"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php _e("These are the number of delivery days which will be considered to display a delivery date by default on checkout page before customer selects delivery date of his choice.", WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr>
                            <tr>
                                <td class="ur-1"><?php _e("Allow scheduling delivery before expected delivery date (If allowed, add extra cost to charge the customer)", WCODD_PLUGIN_SLUG); ?><?php _e(' ( ', WCODD_PLUGIN_SLUG); ?><?php echo get_woocommerce_currency_symbol(); ?><?php _e(' )', WCODD_PLUGIN_SLUG); ?></td>
                                <td class="ur-2">
                                    <input <?php
                                    if (!empty($getwcoddoptionArray) && isset($getwcoddoptionArray['order_delivery_excepted_date_before_order']) && $getwcoddoptionArray['order_delivery_excepted_date_before_order'] == 'on') {
                                        echo $order_delivery_excepted_date_before_order_enable;
                                    }
                                    ?> type="checkbox" name="order_delivery_excepted_date_before_order" class="order_delivery_excepted_date_before_order"  value="on">
                                    <span class="order_delivery_tab_descirtion"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php _e("Enabling this option will let the customer choose the delivery date which is before the standard delivery date. If enabled, you can add the extra fees to charge for letting customer select the delivery date before the standard (expected) delivery date.", WCODD_PLUGIN_SLUG); ?></p>
                                    <?php $beforeCostStyle = (!empty($getwcoddoptionArray) && isset($getwcoddoptionArray['order_delivery_excepted_date_before_order']) && $getwcoddoptionArray['order_delivery_excepted_date_before_order'] == 'on') ? 'display:inline-block;' : 'display:none;' ?>
                                    <p class="order_delivery_before_date_extra_charges">
                                        <input min="0" style="<?php echo $beforeCostStyle; ?>" type="number" value="<?php echo $order_delivery_excepted_date_before_order_extra_cost; ?>" class="onlyNumber order_delivery_before_cost input-text regular-input" name="order_delivery_excepted_date_before_order_extra_cost"  placeholder="Add Extra Cost">
                                    </p>
                                </td>
                            </tr>

                            <tr>
                                <td class="ur-1"><?php _e("Blocked dates for delivery", WCODD_PLUGIN_SLUG); ?></td>
                                <td class="ur-2">
                                    <input class="input-text regular-input" type="text" placeholder = "Order Delivery Date" id="wcodd_multidatepicker" name="order_delivery_enable_disable_date" value="<?php echo!empty($getwcoddoptionArray['order_delivery_enable_disable_date']) ? $getwcoddoptionArray['order_delivery_enable_disable_date'] : ''; ?>">
                                    <span class="order_delivery_tab_descirtion"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php echo __("Enter the dates here which can not be selected by customer, while choosing the delivery date.", WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr>
                            <tr>
                                <td class="ur-1"><?php _e(WCODD_PLUGIN_SELECT_DAYS, WCODD_PLUGIN_SLUG); ?><?php _e(' ( For every week-off day enabled, add extra cost to charge the customer - when this week-off day is selected as delivery date )', WCODD_PLUGIN_SLUG) ?><?php _e(' ( ', WCODD_PLUGIN_SLUG); ?><?php echo get_woocommerce_currency_symbol(); ?><?php _e(' )', WCODD_PLUGIN_SLUG); ?><span class="week-off-badge">Pro </span></td>
                                <td class="forminp">

                                    <div class="order-delivery-week-off">
                                        <img src="<?php echo WODD_PLUGIN_URL . 'admin/images/pro-weekoff.png'; ?>">

                                    </div>

                                    <div class="order-delivery-week-off-desc">
                                        <span class="order_delivery_tab_week_off_descirtion"><i class="fa fa-question-circle"></i></span>
                                    </div>
                                    <p class="block dots-description week-off-description" style="display:none;"><?php _e("Check mark the days which can’t be selected by customer as the delivery date. If you add extra cost for that day, customer will be able to select that day as the delivery date, but he will have to pay the extra cost entered for that day.", WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr>
                            <tr>
                                <td class="ur-1"><?php _e("Add week-off day extra cost if the chosen delivery date is a week-off day", WCODD_PLUGIN_SLUG); ?><span class="week-off-badge">Pro </span></td>
                                <td class="ur-2">
                                    <img src="<?php echo WODD_PLUGIN_URL . 'admin/images/woddchkbox.png'; ?>">
                                    <span class="order_delivery_tab_descirtion woddlast"><i class="fa fa-question-circle"></i></span>
                                    <p class="block dots-description" style="display:none;"><?php _e('Checkmark this box to charge week-off day extra cost to customer, if the chosen delivery date is a week-off day', WCODD_PLUGIN_SLUG); ?></p>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                    <div class="set2">
                        <input name="submit" id="submit2" width="50%" height="15px" class="button button-primary" value="Save Changes" type="submit">
                    </div>
                </div>
            </form>
        </div>
        <?php
    }

    /**
     * Function For dotstore plugin settings
     */
    function contact_supports_dotstore_plugin_settings() {
        ?>
        <form id="cw_plugin_form_id"  > 
            <div class="under-table third-tab">
                <div class="set">
                    <h2><?php echo __("Contact Supports", WCODD_PLUGIN_SLUG); ?></h2>
                </div>
                <table class="wcodd-tableouter">
                    <tbody>  
                        <tr>
                    <iframe src="https://store.multidots.com/dotstore-support/#/home" width="100%" height="500px"></iframe>
                    </tr>
                    </tbody>
                </table>
            </div>
        </form>
        <?php
    }
    