<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://www.multidots.com/
 * @since      1.0.0
 *
 * @package    Woocommerce_Order_Delivery_Date
 * @subpackage Woocommerce_Order_Delivery_Date/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Woocommerce_Order_Delivery_Date
 * @subpackage Woocommerce_Order_Delivery_Date/includes
 * @author     multidots <info@multidots.in>
 */
class Woocommerce_Order_Delivery_Date {

    /**
     * The loader that's responsible for maintaining and registering all hooks that power
     * the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      Woocommerce_Order_Delivery_Date_Loader    $loader    Maintains and registers all hooks for the plugin.
     */
    protected $loader;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $plugin_name    The string used to uniquely identify this plugin.
     */
    protected $plugin_name;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string    $version    The current version of the plugin.
     */
    protected $version;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set the hooks for the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct() {

        $this->plugin_name = 'woocommerce-order-delivery-date';
        $this->version = WCODD_PLUGIN_VERSION;

        $this->load_dependencies();
        $this->set_locale();
        $this->define_admin_hooks();
        $this->define_public_hooks();
    }

    /**
     * Load the required dependencies for this plugin.
     *
     * Include the following files that make up the plugin:
     *
     * - Woocommerce_Order_Delivery_Date_Loader. Orchestrates the hooks of the plugin.
     * - Woocommerce_Order_Delivery_Date_i18n. Defines internationalization functionality.
     * - Woocommerce_Order_Delivery_Date_Admin. Defines all hooks for the admin area.
     * - Woocommerce_Order_Delivery_Date_Public. Defines all hooks for the public side of the site.
     *
     * Create an instance of the loader which will be used to register the hooks
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function load_dependencies() {

        /**
         * The class responsible for orchestrating the actions and filters of the
         * core plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-woocommerce-order-delivery-date-loader.php';

        /**
         * The class responsible for defining internationalization functionality
         * of the plugin.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-woocommerce-order-delivery-date-i18n.php';

        /**
         * The class responsible for defining all actions that occur in the admin area.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-woocommerce-order-delivery-date-admin.php';

        /**
         * The class responsible for defining all actions that occur in the public-facing
         * side of the site.
         */
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-woocommerce-order-delivery-date-public.php';

        $this->loader = new Woocommerce_Order_Delivery_Date_Loader();
    }

    /**
     * Define the locale for this plugin for internationalization.
     *
     * Uses the Woocommerce_Order_Delivery_Date_i18n class in order to set the domain and to register the hook
     * with WordPress.
     *
     * @since    1.0.0
     * @access   private
     */
    private function set_locale() {

        $plugin_i18n = new Woocommerce_Order_Delivery_Date_i18n();
        $plugin_i18n->set_domain($this->get_plugin_name());
        $this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
    }

    /**
     * Register all of the hooks related to the admin area functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_admin_hooks() {

        $plugin_admin = new Woocommerce_Order_Delivery_Date_Admin($this->get_plugin_name(), $this->get_version());
        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
        $this->loader->add_action('admin_post_submit_form_wcodd', $plugin_admin, 'wcodd_add_update_options');
        $this->loader->add_action('admin_post_nopriv_submit_form_wcodd', $plugin_admin, 'wcodd_add_update_options');
        $this->loader->add_action('admin_init', $plugin_admin, 'welcome_order_delivery_date_screen_do_activation_redirect');
        $this->loader->add_action('admin_menu', $plugin_admin, 'adjust_the_wp_menu', 999);
        // save data for timmer settings 
        $this->loader->add_action('admin_post_submit_timer_form_wcodd', $plugin_admin, 'timer_wcodd_add_update_options');
        $this->loader->add_action('admin_post_nopriv_submit_timer_form_wcodd', $plugin_admin, 'timer_wcodd_add_update_options');
        //Custom Dot store menu 
        if (empty($GLOBALS['admin_page_hooks']['dots_store'])) {
            $this->loader->add_action('admin_menu', $plugin_admin, 'dot_store_menu');
        }
            $this->loader->add_action('wp_ajax_add_plugin_userfn_free_wcood', $plugin_admin, 'wp_add_plugin_userfn_free_wcood');
        $this->loader->add_action('wp_ajax_nopriv_add_plugin_userfn_free_wcood', $plugin_admin, 'wp_add_plugin_userfn_free_wcood');
        
        $this->loader->add_action("admin_menu", $plugin_admin, "add_new_menu_items");
        $this->loader->add_filter('post_row_actions', $plugin_admin, 'wc_order_delivery_remove_view_zipcode_post_link', 10, 2);
        $this->loader->add_action("admin_notices", $plugin_admin, "wc_order_delivery_custom_plugin_header");
        $this->loader->add_action("admin_head", $plugin_admin, "wc_order_delivery_custom_plugin_header_style");
    }

    /**
     * Register all of the hooks related to the public-facing functionality
     * of the plugin.
     *
     * @since    1.0.0
     * @access   private
     */
    private function define_public_hooks() {

        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);

        $getwcoddoption = get_option('zpcode_wcodd_option');
        $getwcoddoptionArray = maybe_unserialize($getwcoddoption);

        $plugin_public = new Woocommerce_Order_Delivery_Date_Public($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
        $this->loader->add_action('wp_ajax_nopriv_add_extra_cost_in_product_based_on_delivery_date', $plugin_public, 'add_extra_cost_in_product_based_on_delivery_date');
        $this->loader->add_action('wp_ajax_add_no_extra_cost_in_product_based_on_delivery_date', $plugin_public, 'add_no_extra_cost_in_product_based_on_delivery_date');
        $this->loader->add_action('wp_ajax_nopriv_add_no_extra_cost_in_product_based_on_delivery_date', $plugin_public, 'add_no_extra_cost_in_product_based_on_delivery_date');
        // add another extra cost before order delivery
        $this->loader->add_action('wp_ajax_add_extra_cost_in_product_based', $plugin_public, 'add_extra_cost_in_product_based');
        $this->loader->add_action('wp_ajax_nopriv_add_extra_cost_in_product_based', $plugin_public, 'add_extra_cost_in_product_based');
        $this->loader->add_action('woocommerce_add_order_item_meta', $plugin_public, 'wc_order_delivery_date_add_order_item_meta', 10, 2);
        $this->loader->add_action('woocommerce_after_checkout_billing_form', $plugin_public, 'wc_order_delivery_date_after_checkout_billing_form');
        $this->loader->add_action('woocommerce_email_order_meta', $plugin_public, 'wc_order_delivery_date_email_order_meta', 10, 4);

        $this->loader->add_action('woocommerce_order_details_after_order_table', $plugin_public, 'wc_order_delivery_date_order_details_after_order_table', 10, 1);
        $this->loader->add_filter('woocommerce_locate_template', $plugin_public, 'myplugin_woocommerce_locate_template', 10, 3);
        $this->loader->add_action('woocommerce_checkout_process', $plugin_public, 'wc_order_delivery_checkout_field_order_delivery_required');
        $this->loader->add_action('wp_head', $plugin_public, 'reload_templete_woocommerce_session');
        $this->loader->add_action('woocommerce_cart_calculate_fees', $plugin_public, 'wc_order_delivery_add_fee');
        $this->loader->add_action('wp_ajax_wc_order_delivery_datepicker_date_update', $plugin_public, 'wc_order_delivery_datepicker_date_update');
        $this->loader->add_action('wp_ajax_nopriv_wc_order_delivery_datepicker_date_update', $plugin_public, 'wc_order_delivery_datepicker_date_update');
    }

    /**
     * Run the loader to execute all of the hooks with WordPress.
     *
     * @since    1.0.0
     */
    public function run() {
        $this->loader->run();
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_plugin_name() {
        return $this->plugin_name;
    }

    /**
     * The reference to the class that orchestrates the hooks with the plugin.
     *
     * @since     1.0.0
     * @return    Woocommerce_Order_Delivery_Date_Loader    Orchestrates the hooks of the plugin.
     */
    public function get_loader() {
        return $this->loader;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public function get_version() {
        return $this->version;
    }

}
