<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://www.multidots.com/
 * @since      1.0.0
 *
 * @package    Woocommerce_Order_Delivery_Date
 * @subpackage Woocommerce_Order_Delivery_Date/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Woocommerce_Order_Delivery_Date
 * @subpackage Woocommerce_Order_Delivery_Date/public
 * @author     multidots <info@multidots.in>
 */
class Woocommerce_Order_Delivery_Date_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Woocommerce_Order_Delivery_Date_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Woocommerce_Order_Delivery_Date_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        wp_enqueue_style($this->plugin_name . '-ui', plugin_dir_url(__FILE__) . 'css/jquery-ui.css', array());
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/woocommerce-order-delivery-date-public.css', array(), $this->version, 'all');
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Woocommerce_Order_Delivery_Date_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Woocommerce_Order_Delivery_Date_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);
        if ((!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] == 'on') || (empty($wc_order_delivery_options) || !isset($wc_order_delivery_options['pluginoptionenable']))) {
          //  $order_by_weekend_amount = $wc_order_delivery_options['order_by_weekend_amount'];
            //$off_week_days = $wc_order_delivery_options['selecteddays'];

            if (!empty($wc_order_delivery_options['order_delivery_excepted_date_before_order']) && $wc_order_delivery_options['order_delivery_excepted_date_before_order'] == 'on') {
                $add_another_extra_cost = !empty($wc_order_delivery_options['order_delivery_excepted_date_before_order_extra_cost']) ? $wc_order_delivery_options['order_delivery_excepted_date_before_order_extra_cost'] : '';
            } else {
                $add_another_extra_cost = '';
            }

            $both_text_enable_or_not = !empty($wc_order_delivery_options['order_delivery_both_extra_cost']) ? $wc_order_delivery_options['order_delivery_both_extra_cost'] : '';
            $order_delivery_enable_disable_date = $wc_order_delivery_options['order_delivery_enable_disable_date_publick'];

            $final_odd_array = array();
            $selecteable_date = array();
            /* First time dates blocked logic start */
            $disable_order_delivery_daterange_array2 = array();
            if (!empty($wc_order_delivery_options['order_delivery_excepted_date_before_order']) && $wc_order_delivery_options['order_delivery_excepted_date_before_order'] != 'on') {
                
                $wc_expected_order_delivery_data = $this->add_extra_cost_in_product_based();

                $disable_order_delivery_daterange_array = $this->createDateRangeArray($wc_expected_order_delivery_data['today_date'], $wc_expected_order_delivery_data['wc_odd_expected_date']);

                foreach ($disable_order_delivery_daterange_array as $key => $value) {
                    $disable_order_delivery_daterange_array2[] = date('m/d/Y', strtotime($value));
                }
            }
            $disable_order_delivery_daterange_array_imp = implode(",", $disable_order_delivery_daterange_array2);
            /* First time dates blocked logic end */

            wp_register_script('ajax-js', plugin_dir_url(__FILE__) . 'js/woocommerce-order-delivery-date-public.js', array('jquery'), '', true);
            wp_localize_script('ajax-js', 'ajax_params', array('ajax_url' => admin_url('admin-ajax.php')));
            wp_localize_script('ajax-js', 'get_disable_day_option', array('dayarray' => json_encode($final_odd_array)));
            wp_localize_script('ajax-js', 'get_enable_day_with_price_day_option', array('enable_etxtra_cost_dayarray' => json_encode($selecteable_date)));
            wp_localize_script('ajax-js', 'get_etxtra_cost_before_order', array('add_another_etxtra_cost_before_order' => json_encode($add_another_extra_cost)));
            wp_localize_script('ajax-js', 'both_extra_cost_enable', array('both_extra_cost_enable_or_not' => json_encode($both_text_enable_or_not)));
            wp_localize_script('ajax-js', 'disable_order_delivery_date_admin', array('disable_order_delivery_date_admin' => json_encode($order_delivery_enable_disable_date)));
            wp_localize_script('ajax-js', 'disable_order_delivery_date_first', array('disable_order_delivery_date_first' => json_encode($disable_order_delivery_daterange_array_imp)));
            wp_enqueue_script('ajax-js');
            wp_enqueue_script($this->plugin_name . '-ui', plugin_dir_url(__FILE__) . 'js/jquery-ui.js', array());
            wp_enqueue_script($this->plugin_name . '-multidatespicker', plugin_dir_url(__FILE__) . 'js/jquery-ui.multidatespicker.js', array());
        }
    }

    /**
     * Woocommerce templete override 
     * 
     */
    public function wodd_plugin_path() {

        return untrailingslashit(plugin_dir_path(__FILE__));
    }

    public function myplugin_woocommerce_locate_template($template, $template_name, $template_path) {

        global $woocommerce;

        $_template = $template;

        if (!$template_path)
            $template_path = $woocommerce->template_url;

        $plugin_path = wodd_plugin_path() . '/woocommerce/';

        $template = locate_template(
                array(
                    $template_path . $template_name,
                    $template_name
                )
        );

        // Modification: Get the template from this plugin, if it exists
        if (!$template && file_exists($plugin_path . $template_name))
            $template = $plugin_path . $template_name;

        // Use default template
        if (!$template)
            $template = $_template;

        // Return what we found
        return $template;
    }

    /**
     * This Function for order delievery required fields if setting enable
     */
    public function wc_order_delivery_checkout_field_order_delivery_required() {
        $wc_order_delivery_option = get_option('wcodd_option');
        $getwcoddoptionArray = maybe_unserialize($wc_order_delivery_option);

        if ((!empty($getwcoddoptionArray) && isset($getwcoddoptionArray['pluginoptionenable']) && $getwcoddoptionArray['pluginoptionenable'] == 'on') || (empty($getwcoddoptionArray) && !isset($getwcoddoptionArray['pluginoptionenable']))) {
            if (!empty($getwcoddoptionArray['orderdeliverydatefieldoptionenable']) && $getwcoddoptionArray['orderdeliverydatefieldoptionenable'] != '') {
                if (isset($_POST['odd_deliverydate']) && $_POST['odd_deliverydate'] == '') {
                    wc_add_notice(__('Please select Order Delivery Date'), 'error');
                }
            }
        }
    }

    /**
     * This function for add order delivery information into email template of customer and admin
     *
     * @param unknown_type $order
     * @param unknown_type $sent_to_admin
     * @param unknown_type $plain_text
     * @param unknown_type $email
     */
    public function wc_order_delivery_date_email_order_meta($order, $sent_to_admin, $plain_text, $email) {

        global $wpdb, $woocommerce;

        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);

        if ((!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] == 'on') || (empty($wc_order_delivery_options) && !isset($wc_order_delivery_options['pluginoptionenable']))) {

            $wc_expected_order_delivery_data = WC()->session->get('wc_expected_order_delivery_data');
            $wc_expected_order_delivery_datepicker_date = WC()->session->get('wc_expected_order_delivery_datepicker_data');

            update_post_meta($order->id, "expected_delivery_day", $wc_expected_order_delivery_datepicker_date);

            if (!empty($wc_expected_order_delivery_data)) {
                $wc_odd_expected_day = $wc_expected_order_delivery_data['wc_odd_expected_day'];
                $wc_odd_expected_date = $wc_expected_order_delivery_data['wc_odd_expected_date'];
            }

            $expected_order_delivery_date = date('l jS \of F Y', strtotime($wc_odd_expected_date));
            if (!empty($wc_expected_order_delivery_datepicker_date) && $wc_expected_order_delivery_datepicker_date != '') {
                $order_delivery_item_meta = "<p><b>" . __('Expected delivery date', WCODD_PLUGIN_SLUG) . "</b> " . $wc_expected_order_delivery_datepicker_date . "</p>" . "/n/n";
            } else {
                $order_delivery_item_meta = "<p><b>" . __('Expected delivery date', WCODD_PLUGIN_SLUG) . "</b> " . $expected_order_delivery_date . "</p>" . "/n/n";
            }
        }
    }

    /**
     * Add infromation to order table 
     *
     * @param unknown_type $order
     */
    public function wc_order_delivery_date_order_details_after_order_table($order) {
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);

        if ((!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] == 'on') || (empty($wc_order_delivery_options) && !isset($wc_order_delivery_options['pluginoptionenable']))) {

            $wc_expected_order_delivery_data = WC()->session->get('wc_expected_order_delivery_data');
            $wc_odd_expected_date = '';
            if (!empty($wc_expected_order_delivery_data)) {
                $wc_odd_expected_day = $wc_expected_order_delivery_data['wc_odd_expected_day'];
                $wc_odd_expected_date = $wc_expected_order_delivery_data['wc_odd_expected_date'];
            }

            $expected_order_delivery_date = date('l jS \of F Y', strtotime($wc_odd_expected_date));
            $wc_expected_order_delivery_datepicker_date = WC()->session->get('wc_expected_order_delivery_datepicker_data');
            $wc_expected_order_delivery_datepicker_date = date('l jS \of F Y', strtotime($wc_expected_order_delivery_datepicker_date));
            if (!empty($wc_expected_order_delivery_datepicker_date) && $wc_expected_order_delivery_datepicker_date != '') {
                echo '<p><strong>' . __('Expected delivery date', WCODD_PLUGIN_SLUG) . ':</strong> ' . $wc_expected_order_delivery_datepicker_date . '</p>';
            } else {
                echo '<p><strong>' . __('Expected delivery date', WCODD_PLUGIN_SLUG) . ':</strong> ' . $expected_order_delivery_date . '</p>';
            }
        }
    }

    /**
     * Function for add custom order date in check out page 
     * 
     * 
     */
    public function wc_order_delivery_date_after_checkout_billing_form($checkout) {

        global $wpdb;
        $order_delivery_date_label = "Choose Order Delivery Date";
        $getwcoddoption = get_option('wcodd_option');
        $getwcoddoptionArray = maybe_unserialize($getwcoddoption);
        $required_field = '';
        if ((!empty($getwcoddoptionArray) && isset($getwcoddoptionArray['pluginoptionenable']) && $getwcoddoptionArray['pluginoptionenable'] == 'on') || (empty($getwcoddoptionArray) && !isset($getwcoddoptionArray['pluginoptionenable']))) {

            if (!empty($getwcoddoptionArray['orderdeliverydatefieldoptionenable']) && $getwcoddoptionArray['orderdeliverydatefieldoptionenable'] != '') {
                $required_field = 'required';
            }

            if (!empty($getwcoddoptionArray['orderdeliverycheckoutpagelabel']) && $getwcoddoptionArray['orderdeliverycheckoutpagelabel'] != '') {
                $order_delivery_date_label = $getwcoddoptionArray['orderdeliverycheckoutpagelabel'];
            }
            $selected_diable_date = 'dsfsdfdsf';
            if (!empty($getwcoddoptionArray['order_delivery_enable_disable_date']) && $getwcoddoptionArray['order_delivery_enable_disable_date'] != '') {
                $selected_diable_date = $getwcoddoptionArray['order_delivery_enable_disable_date'];
            }

            if (!empty($getwcoddoptionArray['orderdeliveryoptionenable']) || $getwcoddoptionArray['orderdeliveryoptionenable'] != '' || $getwcoddoptionArray['orderdeliveryoptionenable'] == 'on') {

                woocommerce_form_field('odd_deliverydate', array(
                    'type' => 'text',
                    'label' => __(( $order_delivery_date_label), WCODD_PLUGIN_SLUG),
                    'placeholder' => __(('Choose Order Delivery Date'), WCODD_PLUGIN_SLUG),
                    'required' => !empty($required_field) ? $required_field : '',
                        ), $checkout->get_value('odd_deliverydate'));


                woocommerce_form_field('odd_h_deliverydate', array(
                    'type' => 'text',
                    'custom_attributes' => array('style' => 'display: none !important;')
                        ), $checkout->get_value('odd_h_deliverydate'));

                woocommerce_form_field('odd_h_deliverydate_changes', array(
                    'type' => 'text',
                    'custom_attributes' => array('style' => 'display: none !important;')
                        ), $checkout->get_value('odd_h_deliverydate_changes'));


                woocommerce_form_field('disable_odd_h_deliverydate', array(
                    'type' => 'text',
                    'class' => array('form-row-wide'),
                    'id' => 'disable_order_date',
                    'custom_attributes' => array('attr' => $selected_diable_date, 'style' => 'display: none !important;')
                        ), $checkout->get_value('disable_odd_h_deliverydate'));
            }
        }
    }

    /**
     * Function For Order Fee Add Fee
     * @global type $woocommerce
     */
    public function wc_order_delivery_add_fee() {
        global $woocommerce;
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);
        if ((!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] == 'on') || (empty($wc_order_delivery_options) && !isset($wc_order_delivery_options['pluginoptionenable']))) {

            $add_another_extra_cost_before_order_deliver = WC()->session->get("add_extra_cost_before_order_delivery_date");
            $delivery_date_extra_cost = WC()->session->get("order_delivery_with_extra_cost");

            if (isset($add_another_extra_cost_before_order_deliver) && !empty($add_another_extra_cost_before_order_deliver)) {
                //Add fee for before order delivery date
                $woocommerce->cart->add_fee("Extra Charges Before Expected Delivery Date", $add_another_extra_cost_before_order_deliver);
            }

            //Add fee for Week-Off Days
            if (isset($delivery_date_extra_cost) && !empty($delivery_date_extra_cost)) {
                $woocommerce->cart->add_fee($delivery_date_extra_cost['key'], $delivery_date_extra_cost['value']);
            }
        }
    }

    /**
     * Function For add no extra cost without click 
     * 
     * 
     */
    public function add_no_extra_cost_in_product_based_on_delivery_date() {
        global $woocommerce;
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);
        if (!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] != 'on') {
            $delivery_date_extra_cost = array();
            echo json_encode($delivery_date_extra_cost);
            wp_die();
        }
        $extra_cost = array();
        WC()->session->set("order_delivery_with_extra_cost", $extra_cost);
        $delivery_date_extra_cost = WC()->session->get("order_delivery_with_extra_cost");
        echo json_encode($delivery_date_extra_cost);
        die();
    }

    /**
     * Function For remove session data 
     * 
     */
    public function reload_templete_woocommerce_session() {
        global $wpdb, $woocommerce;
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);
        if ((!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] == 'on') || (empty($wc_order_delivery_options) && !isset($wc_order_delivery_options['pluginoptionenable']))) {

            if (is_checkout()) {
                WC()->session->set("order_delivery_with_extra_cost", "");
                WC()->session->set("add_extra_cost_before_order_delivery_date", "");
            }
        }
    }

    /**
     * Function For add extra cost before order delivery date ajax function 
     * 
     */
    public function add_extra_cost_in_product_based() {
        global $wpdb;

        $current_user_id = get_current_user_id();
        $billing_postcode = get_user_meta($current_user_id, 'billing_postcode', true);

        $add_another_exta_cost = !empty($_POST['add_another_extra_cost_before_order']) ? $_POST['add_another_extra_cost_before_order'] : ' ';
        $dateText = !empty($_POST['dateText']) ? $_POST['dateText'] : ' ';
        $expected_order_delivery_date = '';
        $wc_expected_order_delivery_data = '';
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);

        if (!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] != 'on') {
            wp_die();
        }

        $wc_order_delivery_standard_order_delivery_day = !empty($wc_order_delivery_options['selectstanderdorderdate']) ? $wc_order_delivery_options['selectstanderdorderdate'] : 4;
        //If Minimum Selecteble Day is 0 then count expected date from current date
        $order_delivery_enable_disable_date_results = '';

//        $wc_order_delivery_option = get_option('wcodd_option');
//        $ wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);
        $order_delivery_enable_disable_date = $wc_order_delivery_options['order_delivery_enable_disable_date_publick'];

        if (!empty($order_delivery_enable_disable_date) && $order_delivery_enable_disable_date != '') {
            $order_delivery_enable_disable_date_results = explode(",", $order_delivery_enable_disable_date);
        }

        $expected_order_delivery_date = date_i18n('Y-m-d', strtotime("+$wc_order_delivery_standard_order_delivery_day day"));
        $start_date = date_i18n('Y-m-d');

        $expected_order_delivery_timestamp = strtotime($expected_order_delivery_date);
        $expected_order_delivery_day = date('D', strtotime($expected_order_delivery_timestamp));

        if (!empty($wc_order_delivery_disable_days) && isset($wc_order_delivery_disable_days) && is_array($wc_order_delivery_disable_days)) {
            if (is_array($wc_order_delivery_disable_days) && in_array($expected_order_delivery_day, $wc_order_delivery_disable_days)) {
                $expected_order_delivery_date = date_i18n('Y-m-d', strtotime("+$wc_order_delivery_standard_order_delivery_day day"));
            }
        }

        // check exceptable date
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);
       // $order_by_weekend_amount = $wc_order_delivery_options['order_by_weekend_amount'];
       // $off_week_days = $wc_order_delivery_options['selecteddays'];
        $add_another_extra_cost = !empty($wc_order_delivery_options['order_delivery_excepted_date_before_order_extra_cost']) ? $wc_order_delivery_options['order_delivery_excepted_date_before_order_extra_cost'] : '';

        $both_text_enable_or_not = !empty($wc_order_delivery_options['order_delivery_both_extra_cost']) ? $wc_order_delivery_options['order_delivery_both_extra_cost'] : '';
        $order_delivery_enable_disable_date = $wc_order_delivery_options['order_delivery_enable_disable_date_publick'];
        if (defined('DOING_AJAX') && DOING_AJAX) {
            /* selected date and zipcode by generated date compare */
            $expected_order_delivery_date_final_date = date_i18n('Y-m-d', strtotime($dateText));
            $add_extra_before_cost = '';
            if ($expected_order_delivery_date > $expected_order_delivery_date_final_date) {
                $add_extra_before_cost = $add_another_exta_cost;
            } elseif ($expected_order_delivery_date < $expected_order_delivery_date_final_date) {
                $add_extra_before_cost = "";
            }
            WC()->session->set('wc_expected_order_delivery_data', $wc_expected_order_delivery_data);

            WC()->session->set('wc_expected_order_delivery_datepicker_data', $dateText);

            WC()->session->set("add_extra_cost_before_order_delivery_date", $add_extra_before_cost);

            $expected_order_delivery_date = date('l jS \of F Y', strtotime($dateText));
            $excepted_order_delivery_based_message = "Your expected delivery day is $expected_order_delivery_date.";

            echo $excepted_order_delivery_based_message;
            die();
        } else {

            $wc_expected_order_delivery_data['today_date'] = $start_date;
            //$wc_expected_order_delivery_data['zip_based_delivery_enable'] = $zipcode_based_delivery_option_enable_deseble_check['zipcodebaseddeliveryoptionenable'];

            return $wc_expected_order_delivery_data;
        }
    }

    /**
     * Function For add extra cost based on admin settings 
     * 
     */
    public function wc_order_delivery_datepicker_date_update() {
        $excepted_order_delivery_based_message = '';
        if (isset($_POST['order_date_value']) && !empty($_POST['order_date_value']) && $_POST['order_date_value'] != '') {
            $dateText = $_POST['order_date_value'];
            $expected_order_delivery_date = date('l jS \of F Y', strtotime($dateText));
            $excepted_order_delivery_based_message = "Your expected delivery day is $expected_order_delivery_date.";
        }
        echo $excepted_order_delivery_based_message;
        wp_die();
    }

    /**
     * Add Expected delivery date and day into WooCommerce Order meta
     *
     */
    public function wc_order_delivery_date_add_order_item_meta($item_id, $cart_item) {

        $wc_expected_order_delivery_data = WC()->session->get('wc_expected_order_delivery_data');
        $wc_odd_expected_day = '';
        $wc_odd_expected_date = '';
        $wc_order_delivery_option = get_option('wcodd_option');
        $wc_order_delivery_options = maybe_unserialize($wc_order_delivery_option);

        if ((!empty($wc_order_delivery_options) && isset($wc_order_delivery_options['pluginoptionenable']) && $wc_order_delivery_options['pluginoptionenable'] == 'on') || (empty($wc_order_delivery_options) && !isset($wc_order_delivery_options['pluginoptionenable']))) {

            if (!empty($wc_expected_order_delivery_data)) {
                $wc_odd_expected_day = $wc_expected_order_delivery_data['wc_odd_expected_day'];
                $wc_odd_expected_date = $wc_expected_order_delivery_data['wc_odd_expected_date'];
            }

            $expected_order_delivery_date = date('l jS \of F Y', strtotime($wc_odd_expected_date));
            $wc_expected_order_delivery_datepicker_date = WC()->session->get('wc_expected_order_delivery_datepicker_data');
            if (!empty($wc_expected_order_delivery_datepicker_date) && $wc_expected_order_delivery_datepicker_date != '') {
                $order_delivery_item_meta = '<p><strong>' . __('Expected delivery date', WCODD_PLUGIN_SLUG) . ':</strong> ' . $wc_expected_order_delivery_datepicker_date . '</p>';
                woocommerce_add_order_item_meta($item_id, '_expected_delivery_date', $wc_expected_order_delivery_datepicker_date);
            } else {
                $order_delivery_item_meta = '<p><strong>' . __('Expected delivery date', WCODD_PLUGIN_SLUG) . ':</strong> ' . $expected_order_delivery_date . '</p>';
                woocommerce_add_order_item_meta($item_id, '_expected_delivery_date', $expected_order_delivery_date);
            }
        }
    }

    public function createDateRangeArray($strDateFrom, $strDateTo) {
        // takes two dates formatted as YYYY-MM-DD and creates an
        // inclusive array of the dates between the from and to dates.
        // could test validity of dates here but I'm already doing
        // that in the main script

        $aryRange = array();

        $iDateFrom = mktime(1, 0, 0, substr($strDateFrom, 5, 2), substr($strDateFrom, 8, 2), substr($strDateFrom, 0, 4));
        $iDateTo = mktime(1, 0, 0, substr($strDateTo, 5, 2), substr($strDateTo, 8, 2), substr($strDateTo, 0, 4));

        if ($iDateTo >= $iDateFrom) {
            array_push($aryRange, date('Y-m-d', $iDateFrom)); // first entry
            while ($iDateFrom < $iDateTo) {
                $iDateFrom+=86400; // add 24 hours
                array_push($aryRange, date('Y-m-d', $iDateFrom));
            }
        }
        return $aryRange;
    }

}

function order_delivery_plugin_path() {
    return untrailingslashit(plugin_dir_path(__FILE__));
}
